@@ -22,9 +22,9 @@ class raw_env(RLCardBase):
 
     metadata = {'render.modes': ['human']}
 
-    def __init__(self, seed=None):
+    def __init__(self):
         self.agents = ['landlord_0', 'peasant_0', 'peasant_1']
-        super().__init__("doudizhu", 3, (6, 5, 15), seed)
+        super().__init__("doudizhu", 3, (6, 5, 15))
 
     def _scale_rewards(self, reward):
         # Maps 1 to 1 and 0 to -1
