@@ -20,8 +20,8 @@ class raw_env(RLCardBase):
 
     metadata = {'render.modes': ['human']}
 
-    def __init__(self, seed=None):
-        super().__init__("mahjong", 4, (6, 34, 4), seed)
+    def __init__(self):
+        super().__init__("mahjong", 4, (6, 34, 4))
 
     def render(self, mode='human'):
         for player in self.agents:
