@@ -4,10 +4,10 @@ from pettingzoo.utils.to_parallel import parallel_wrapper_fn
 
 
 class raw_env(SimpleEnv):
-    def __init__(self, seed=None, N=2, max_frames=100):
+    def __init__(self, N=2, max_frames=100):
         scenario = Scenario()
         world = scenario.make_world(N=2)
-        super().__init__(scenario, world, max_frames, seed)
+        super().__init__(scenario, world, max_frames)
 
 
 env = make_env(raw_env)
