@@ -19,9 +19,7 @@ def save_observation(env, agent=None, all_agents=False, save_dir=os.getcwd()):
         agent = env.agent_selection
     agent_list = [agent]
     if all_agents:
-        agent_list = []
-        for a in env.agent_order:
-            agent_list.append(a)
+        agent_list = env.agents[:]
     for a in agent_list:
         _check_observation_saveable(env, a)
         save_folder = "{}/{}".format(save_dir, env.__module__)
